@@ -1,9 +1,9 @@
 # document.py
 
 # noinspection PyUnresolvedReferences
-from live_api.endpoint import *
+from live_api.endpoints import *
 # noinspection PyUnresolvedReferences
-from live_api.engine import *
+from live_api.service import *
 
 from live_api.base import document
 
